OC.L10N.register(
    "core",
    {
    "Please select a file." : "יש לבחור קובץ.",
    "File is too big" : "הקובץ גדול מדי",
    "The selected file is not an image." : "הקובץ שנבחר אינו קובץ תמונה",
    "The selected file cannot be read." : "לא ניתן לקרוא את הקובץ שנבחר",
    "Invalid file provided" : "סופק קובץ לא חוקי",
    "No image or file provided" : "לא סופקו תמונה או קובץ",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "An error occurred. Please contact your admin." : "אירעה שגיאה. יש ליצור קשר עם המנהל שלך.",
    "No temporary profile picture available, try again" : "לא קיימת תמונת פרופיל זמנית, יש לנסות שוב",
    "No crop data provided" : "לא סופק מידע קיטום",
    "No valid crop data provided" : "לא סופק מידע קיטום חוקי",
    "Crop is not square" : "הקיטום אינו מרובע",
    "State token does not match" : "קוד אימות מצב אינו תואם",
    "Invalid app password" : "ססמת היישומון שגויה",
    "Could not complete login" : "לא ניתן להשלים את הכניסה",
    "Your login token is invalid or has expired" : "אסימון הכניסה שלך שגוי או שהוא פג",
    "Password reset is disabled" : "אין אפשרות לאפס סיסמה",
    "Couldn't reset password because the token is invalid" : "לא ניתן לאפס ססמה כיוון שאסימון האימות אינו חוקי",
    "Couldn't reset password because the token is expired" : "לא ניתן לאפס ססמה כיוון שפג תוקפו של אסימון האימות",
    "%s password reset" : "%s הסיסמא אופסה",
    "Password reset" : "איפוס סיסמה",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "יש ללחוץ על הכפתור הבא בכדי לאפס סיסמה, אם איפוס הסיסמה לא התבקש יש להתעלם מהודעה זו",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "יש ללחוץ על הקישור הבא בכדי לאפס סיסמה, אם איפוס הסיסמה לא התבקש יש להתעלם מהודעה זו",
    "Reset your password" : "יש לאפס סיסמה",
    "Nextcloud Server" : "שרת Nextcloud",
    "Some of your link shares have been removed" : "חלק מקישורי השיתופים שלך הוסרו",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "עקב תקלת אבטחה נאלצנו להסיר חלק מקישורי השיתופים שלך. נא להיכנס לקישור לקבלת פרטים נוספים.",
    "The user limit of this instance is reached." : "מגבלת המשתמשים של מופע זה הושגה.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "הזן את מפתח המנוי שלך כדי להגדיל את מגבלת המשתמשים. למידע נוסף על Nextcloud Enterprise, עיין באתר שלנו.",
    "Preparing update" : "מכין עדכון",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "שלב בתיקון:",
    "Repair info:" : "פרטי תיקון:",
    "Repair warning:" : "אזהרת תיקון:",
    "Repair error:" : "שגיאת תיקון:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "יש להשתמש בעדכון על בסיס שורת פקודה כיוון שעדכון אוטומטי מנוטרל בקובץ config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: בודק טבלה %s",
    "Turned on maintenance mode" : "הפעלת מצב אחזקה",
    "Turned off maintenance mode" : "כיבוי מצב אחזקה",
    "Maintenance mode is kept active" : "מצב אחזקה נשמר פעיל",
    "Updating database schema" : "עדכון סכימת מסד נתונים",
    "Updated database" : "עדכון מסד נתונים",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
    "Checked database schema update" : "עדכון סכימת מסד נתונים נבדק",
    "Checking updates of apps" : "בדיקת עדכוני יישומים",
    "Checking for update of app \"%s\" in appstore" : "בודק עדכונים עבור האפליקציות \"%s\" בחנות האפליקציות.",
    "Update app \"%s\" from appstore" : "עדכן אפליקציה \"%s\" מחנות האפליקציות",
    "Checked for update of app \"%s\" in appstore" : "חיפוש אם קיים עדכון ליישומון „%s” בחנות היישומונים.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים עבור %s ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
    "Checked database schema update for apps" : "עדכון סכימת מסד נתונים ליישומים נבדק",
    "Updated \"%1$s\" to %2$s" : "„%1$s” עודכן לכדי %2$s",
    "Set log level to debug" : "קביעת רמת דיווח לתהליך ניפוי בשגיאות",
    "Reset log level" : "קביעה מחדש לרמת דיווח",
    "Starting code integrity check" : "התחלת בדיקת תקינות קוד",
    "Finished code integrity check" : "סיום בדיקת תקינות קוד",
    "%s (incompatible)" : "%s (לא תואם)",
    "The following apps have been disabled: %s" : "היישומים הבאים הושבתו: %s",
    "Already up to date" : "כבר עדכני",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "שרת האינטרנט לא מוגדר עדיין כראוי כדי לאפשר סנכרון קבצים, כיוון שמנשק ה־WebDAV כנראה אינו מתפקד.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך אינו מוגדר כראוי כדי לפתור את „{url}”. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "שרת האינטרנט שלך אינו מוגדר כראוי לפתור את ה-\"{url}\". קרוב לוודאי שזה קשור לתצורה של שרת אינטרנט שלא עודכנה כדי לספק תיקיה זו ישירות. אנא השווה את התצורה שלך עם כללי השכתוב שנשלחו ב- \"htaccess.\" עבור Apache או זה שמופיע בתיעוד עבור Nginx בדף התיעוד שלו. ב- Nginx, אלה בדרך כלל השורות המתחילות ב- \"location ~\" שצריכים עדכון.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך אינו מוגדר כראוי למסירת קבצי woff2.. זו בדרך כלל בעיה בתצורת ה-Nginx. עבור Nextcloud 15 הוא זקוק להתאמה כדי לספק גם קבצי woff2.. השווה את תצורת ה-Nginx שלך לתצורה המומלצת <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">בתיעוד</a> שלנו.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "מסתבר כי PHP לא מוגדר כראוי כדי לתשאל משתני סביבה. הבדיקה עם getenv(\"PATH\") מחזירה תשובה ריקה בלבד.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "נא לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד למתקינים ↖️</a> להערות בנוגע להגדרות PHP והגדרות ה־PHP לשרת שלך, במיוחד אם נעשה שימוש ב־php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "הופעלה תצורה לקריאה בלבד. מצב זה מונע את הגדרת חלק מההגדרות דרך מנשק דפדפן. יתרה מכך, יש להפוך את הקובץ למורשה לכתיבה ידנית בכל עדכון מחדש.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "מסד הנתונים שלך לא עובד עם רמת הפרדת פעולות של „READ COMMITTED” . מצב כזה יכול לגרום לבעיות כאשר מספר פעולות רצות במקביל.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "מודול ה־PHP בשם „fileinfo” חסר. מומלץ בחום להפעיל את המודול הזה כדי לקבל את התוצאות הטובות ביותר בזיהוי סוג MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "נעילת קבצים מושבתת בזמן פעילות, מצב כזה יכול לגרום לתקלות במקרים של תחרות על משאב. יש להפעיל את „filelocking.enabled” ב־config.php כדי להתעלם מתקלות שכאלה. יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד ↖️</a> לקבלת מידע נוסף.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "אם המערכת שלך אינה מותקנת בשורש שם המתחם ומשתמשת ב־cron של המערכת, עשויות לצוץ תקלות עם יצירת כתובות. כדי להימנע מהתקלות האלו, נא להגדיר את האפשרות „overwrite.cli.url” בקובץ ה־config.php של נתיב שורש ההתקנה שלך (הצעה: „{suggestedOverwriteCliURL}”)",
    "Your installation has no default phone region set. This is required to be able to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the wished region." : "לא הגדרת אזור הטלפון כברירת מחדל להתקנה שלך. זה נדרש כדי לאפשר לאמת מספרי טלפון בהגדרות הפרופיל ללא קוד מדינה. כדי לאפשר מספרים ללא קוד מדינה, הוסף \"default_phone_region\" עם קוד ISO 3166-1 המתאים לאזור הרצוי.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את משימות ה־cron דרך שורת פקודה. השגיאות הטכניות הבאות התרחשו:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "משימת הרקע האחרונה פעלה במשך {relativeTime}. כנראה שמדובר בתקלה כלשהי.",
    "Check the background job settings" : "בדיקת הגדרות משימות רקע",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "לשרת זה אין חיבור לאינטרנט: מגוון נקודות קצה אינן נגישות. משמעות הדבר היא שחלק מהתכונות כגון עיגון אחסון חיצוני, הודעות על עדכונים או התקנות של יישומי צד שלישי לא יעבדו. גישה לקבצים מרחוק ושליחת הודעות בדוא״ל לא יעבדו גם כן. אנו ממליצים להפעיל את החיבור של השרת הזה לאינטרנט כדי שתהיה אפשרות ליהנות מכל התכונות.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "לא הוגדר מטמון זיכרון. כדי לשפר את הביצועים, נא להגדיר מטמון זיכרון (memcache), אם ניתן. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "אין מקור מתאים לאקראיות שנמצא על ידי PHP, שמאוד לא מומלץ מטעמי אבטחה. מידע נוסף ניתן למצוא <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">בתיעוד</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "גרסת ה־PHP שמותקנת אצלך היא {version}. נא לשדרג את גרסת ה־PHP שלך כדי לנצל את <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">עדכוני הביצועים והאבטחה שמסופקים על ידי קבוצת PHP</a> ברגע שההפצה שלך משחררת אותן.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 הוא המהדורה האחרונה התומכת ב- PHP 7.2. \nNextcloud 21 דורש לפחות PHP 7.3.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "תצורת הכותרת של המתווך ההפוך שגויה או שהגישה שלך אל Nextcloud מתבצעת ממתווך מהימן. אם לא כך המצב, מדובר בפרצת אבטחה שיכולה לאפשר לתוקף לזייף כתובת IP כפי שהיא מיוצגת מול ה־Nextcloud. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached מוגדר כמטמון מופץ, אבל מודול ה־PHP השגוי המותקן הוא „memcache”.‏ ‎\\OC\\Memcache\\Memcached תומך רק ב־„memcached” ולא ב־ „memcache”. ניתן לצפות ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">וויקי של memcached לגבי שני המודולים</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "חלק מהקבצים לא עברו את בדיקת השלמות. ניתן למצוא מידע נוסף על אופן הפתרון של תקלה זו ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">רשימת קבצים שגויים…</a> / <a href=\"{rescanEndpoint}\">סריקה מחדש…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "מודול ה- PHP OPcache לא נטען. \nלקבלת ביצועים טובים יותר, מומלץ לטעון אותו להתקנת ה- PHP שלך.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "ה־OPcache של PHP אינו מוגדר כראוי. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">לשיפור הביצועים אנו ממליצים</a> להשתמש בהגדרות הבאות בקובץ <code>php.ini</code>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "ל־PHP שלך אין תמיכה ב־FreeType. מצב כזה יגרום לתמונות פרופיל משובשות לצד מנשק הגדרות משובש.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "חסר אינדקס „{indexName}” בטבלה „{tableName}”.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
    "Missing primary key on table \"{tableName}\"." : "חסר מפתח ראשי בטבלה \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "חסרה עמודה האופציונלית \"{columnName}\" בטבלה \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "במופע זה חסרים כמה מודולי PHP מומלצים. לשיפור ביצועים ותאימות טובה יותר, מומלץ להתקין אותם.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "למודול php-imagick במקרה הזה אין תמיכה ב- SVG. לקבלת תאימות טובה יותר, מומלץ להתקין אותו.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "בחלק מהעמודות במסד הנתונים חסרה המרה ל- big int. בשל העובדה ששינוי סוגי העמודות בטבלאות גדולות עלול לארוך זמן מה, לא שינו אותן באופן אוטומטי. על ידי הפעלת 'occ db: convert-filecache-bigint', ניתן היה להחיל את השינויים הממתינים באופן ידני. יש לבצע פעולה זו בזמן שהמופע לא מקוון. לפרטים נוספים, קראו את<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> עמוד התיעוד בנושא זה</a>.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite הוא מנגנון מסד הנתונים נכון לעכשיו. במערכות גדולות מוטב להחליף למנגנון מסד נתונים אחר.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "מצב זה מומלץ במיוחד כאשר מריצים את לקוח שולחן העבודה לסנכרון קבצים.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "כדי להגר למסד נתונים אחר יש להשתמש בכלי שורת הפקודה: ‚occ db:convert-type’, או לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד ↖️</a>.",
    "The PHP memory limit is below the recommended value of 512MB." : "מגבלת הזיכרון של ה־PHP היא מתחת לערך המומלץ על סך 512 מ״ב.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ספריות אפליקציות מסוימות הן בבעלות משתמש אחר מזה של שרת האינטרנט. זה יכול להיות במקרה שאפליקציות הותקנו באופן ידני. בדוק את ההרשאות של ספריות האפליקציות הבאות:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL משמש כמסד נתונים, אך אינו תומך בתווים של 4 בתים. כדי להיות מסוגל לטפל בתווים של 4 בתים (כמו אימוג'יים) ללא בעיות בשמות קבצים או הערות למשל, מומלץ לאפשר את תמיכה ב-4 בתים ב- MySQL. לפרטים נוספים, קראו את <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">עמוד התיעוד בנושא זה</a>.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "מופע זה משתמש באיחסון אובייקטים מבוססת S3 כאחסון ראשי. הקבצים שהועלו מאוחסנים באופן זמני בשרת, ולכן מומלץ שיהיה שטח פנוי של 50 GB בספריית ה- temp של PHP. בדוק ביומנים לקבלת יותר פרטים על הנתיב והשטח הזמין. כדי לשפר זאת, אנא שנה את הספריה הזמנית ב- php.ini, או תפנה יותר מקום בנתיב זה.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "אתה ניגש למופע שלך באמצעות חיבור מאובטח, אולם המופע שלך מייצר כתובות אתרים לא מאובטחות. ככל הנראה פירוש הדבר שאתה עומד מאחורי שרת reverse proxy, ומשתני ה-overwrite config אינם מוגדרים בצורה נכונה. אנא קרא<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> את דף התיעוד בנושא זה</a>.",
    "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "לפרטים נוספים, עיין<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\"> בתיעוד</a>.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "תיקיית הנתונים והקבצים שלך כנראה נגישים דרך האינטרנט. קובץ ה־‎.htaccess אינו עובד. מומלץ בחום להגדיר את השרת שלך כך שתיקיית הנתונים אינה נגישה עוד או לחלופין להעביר את תיקיית הנתונים אל מחוץ לתיקיית השורש של שירות אירוח האתרים.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. מדובר בפרצת אבטחה או פרטיות, מומלץ להתאים את ההגדרה הזאת בהתאם.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. יתכן שחלק מהתכונות לא תעבודנה כראוי, מומלץ להתאים את ההגדרה הזאת בהתאם.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה-HTTP, הנקרא \"{header}\", אינה מכילה \"{expected}\". זהו סיכון אפשרי של אבטחה או פרטיות, שכן מומלץ להתאים הגדרה זו בהתאם.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "כותרת ה-HTTP הנקרא \"{header}\", אינה מוגדרת כ-\n\"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" או \"{val5}\".\nזה יכול לדלוף מידע על הפניות. ראה המלצת W3C ↗.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "כותרת ה־HTTP בשם „Strict-Transport-Security” אינה מוגדרת עד לפחות „{seconds}” שניות. לטובת אבטחה מוגברת אנו ממליצים להפעיל HSTS כפי שמתואר ב<a href=\"{docUrl}\" rel=\"noreferrer noopener\">עצות האבטחה ↖️</a> שלנו.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "גישה לאתר בצורה לא מאובטחת באמצעות HTTP. מומלץ מאוד להגדיר את השרת שלך לחייב HTTPS במקום HTTP, כמתואר בעצות אבטחה ↗.",
    "unknown text" : "מלל לא מוכר",
    "Hello world!" : "שלום עולם!",
    "sunny" : "שמשי",
    "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
    "Hello {name}" : "שלום {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
    "new" : "חדש",
    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים","התקבלו %n קבצים"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "העדכון מתבצע, יציאה מהעמוד הזה עשויה להפריע לתהליך בסביבות מסוימות.",
    "Update to {version}" : "עדכון ל־{version}",
    "An error occurred." : "אירעה שגיאה.",
    "Please reload the page." : "יש להעלות מחדש דף זה.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון לא בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "העדכון לא הצליח. נא לדווח על התקלה הזאת ל<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">קהילת Nextcloud</a>.",
    "Continue to Nextcloud" : "להמשיך ל־Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד שנייה.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות.","העדכון הצליח. תתבצע העברה ל־Nextcloud בעוד %n שניות."],
    "Log in" : "כניסה",
    "Logging in …" : "מתבצעת כניסה…",
    "Server side authentication failed!" : "אימות לצד שרת נכשל!",
    "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
    "An internal error occurred." : "אירעה שגיאה פנימית.",
    "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
    "Username or email" : "שם משתמש או דואר אלקטרוני",
    "Password" : "ססמה",
    "Wrong username or password." : "שם המשתמש או הססמה שגויים.",
    "User disabled" : "משתמש מושבת",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
    "Your account is not setup for passwordless login." : "החשבון שלך לא מוגדר לכניסה בלי ססמה.",
    "Passwordless authentication is not supported in your browser." : "אימות ללא ססמה אינו נתמך על ידי הדפדפן שלך.",
    "Passwordless authentication is only available over a secure connection." : "אימות ללא סיסמה הוא זמין רק דרך חיבור מאובטח.",
    "Reset password" : "איפוס ססמה",
    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "הודעת איפוס סיסמה נשלחה לכתובת הדואר האלקטרוני של חשבון זה. אם אינך מקבל אותו, בדוק את תיקיות דואר הספאם/זבל שלך, או בקש עזרה ממנהל המקומי שלך.",
    "If it is not there ask your local administrator." : "אם זה לא נמצא, שאל את המנהל המקומי שלך.",
    "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
    "Password can not be changed. Please contact your administrator." : "לא ניתן לשנות את הססמה. יש לפנות למנהל שלך.",
    "Back to login" : "חזרה לכניסה",
    "New password" : "ססמה חדשה",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "הקבצים שלך מוצפנים. לא תהיה שום דרך להחזיר את הנתונים לאחר איפוס הסיסמה. אם אינך בטוח מה לעשות, פנה למנהל המערכת לפני שתמשיך. האם אתה באמת רוצה להמשיך?",
    "I know what I'm doing" : "אני יודע/ת מה אני עושה",
    "Resetting password" : "איפוס ססמה",
    "Recommended apps" : "יישומונים מומלצים",
    "Loading apps …" : "היישומונים נטענים…",
    "Could not fetch list of apps from the app store." : "לא ניתן לקבל את רשימת היישומונים מחנות היישומונים.",
    "Installing apps …" : "היישומונים מותקנים…",
    "App download or installation failed" : "הורדת או התקנת היישומון נכשלה",
    "Can't install this app because it is not compatible" : "לא ניתן להתקין את היישומון הזה כיוון שאינו נתמך.",
    "Can't install this app" : " לא ניתן להתקין את היישומון הזה",
    "Cancel" : "ביטול",
    "Schedule work & meetings, synced with all your devices." : "תזמון עבודה ופגישות בסנכרון עם כל המכשירים שלך.",
    "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "צ'אטים, שיחות וידאו, שיתוף מסך, פגישות מקוונות ועידת אינטרנט - בדפדפן ובאפליקציות סלולריות.",
    "Collaboratively edit office documents." : "עריכה שיתופית של מסמכי Office.",
    "Local document editing back-end used by the Collabora Online app." : "עריכת מסמך מקומי באופן back-end המשמשת את אפליקציית Collabora Online.",
    "Forgot password?" : "שכחת ססמה?",
    "Log in with a device" : "כניסה עם מכשיר",
    "Back" : "חזרה",
    "Reset search" : "איפוס החיפוש",
    "Search for {name} only" : "חפש ל-{name} בלבד",
    "No results for {query}" : "אין תוצאות עבור {query}",
    "Start typing to search" : "להתחלת החיפוש יש להקליד",
    "Loading more results …" : "נטענות תוצאות נוספות…",
    "Load more results" : "לטעון עוד תוצאות",
    "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
    "Search {types} …" : "חפש {types} ...",
    "Settings" : "הגדרות",
    "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
    "Search contacts …" : "חיפוש אנשי קשר…",
    "No contacts found" : "לא נמצאו אנשי קשר",
    "Show all contacts …" : "הצגת כל אנשי הקשר…",
    "Install the Contacts app" : "התקנת יישומון אנשי הקשר",
    "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
    "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
    "No" : "לא",
    "Yes" : "כן",
    "No files in here" : "אין כאן קבצים",
    "New folder" : "תיקייה חדשה",
    "No more subfolders in here" : "אין כאן עוד תת־תיקיות",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"/\" is not allowed inside a file name." : "אסור להשתמש ב־„/” בתוך שם קובץ.",
    "\"{name}\" is not an allowed filetype" : "סוד הקובץ „{name}” אינו מורשה",
    "{newName} already exists" : "{newName} כבר קיים",
    "Choose" : "בחירה",
    "Copy" : "העתקה",
    "Move" : "העברה",
    "Error loading file picker template: {error}" : "שגיאה בטעינת תבנית בחירת הקבצים: {error}",
    "OK" : "אישור",
    "Error loading message template: {error}" : "שגיאה בטעינת תבנית ההודעות: {error}",
    "read-only" : "לקריאה בלבד",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} הנגשות קובץ","{count} התנגשויות קבצים","{count} התנגשויות קבצים","{count} התנגשויות קבצים"],
    "One file conflict" : "התנגשות קובץ אחת",
    "New Files" : "קבצים חדשים",
    "Already existing files" : "קבצים קיימים כבר",
    "Which files do you want to keep?" : "אילו קבצים ברצונך לשמור?",
    "If you select both versions, the copied file will have a number added to its name." : "אם תבחר האפשרות לשמור את שתי הגרסאות, לשם קובץ המועתק יתווסף מספר.",
    "Continue" : "המשך",
    "(all selected)" : "(הכול נבחר)",
    "({count} selected)" : "({count} נבחרו)",
    "Error loading file exists template" : "שגיאה בטעינת קובץ תבנית קיימים",
    "Pending" : "בהמתנה",
    "Copy to {folder}" : "העתקה אל {folder}",
    "Move to {folder}" : "העברה אל {folder}",
    "Saving …" : "מתבצעת שמירה…",
    "Authentication required" : "נדרש אימות",
    "This action requires you to confirm your password" : "פעולה זו דורשת ממך לאמת את הססמה שלך",
    "Confirm" : "אימות",
    "Failed to authenticate, try again" : "האימות נכשל, נא לנסות שוב",
    "seconds ago" : "שניות",
    "Connection to server lost" : "החיבור לשרת אבד",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["תקלה בטעינת העמוד, יתבצע רענון בעוד שנייה","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות"],
    "Add to a project" : "הוספה למיזם",
    "Show details" : "הצגת פרטים",
    "Hide details" : "הסתרת פרטים",
    "Rename project" : "שינוי שם מיזם",
    "Failed to rename the project" : "שינוי שם המיזם נכשל",
    "Failed to create a project" : "יצירת המיזם נכשלה",
    "Failed to add the item to the project" : "הוספת פריט למיזם נכשלה",
    "Connect items to a project to make them easier to find" : "יש לחבר פריטים למיזם כדי להקל על איתורם",
    "Type to search for existing projects" : "לחיפוש במיזמים הקיימים יש להקליד",
    "New in" : "חדש ב־",
    "View changelog" : "הצגת יומן שינויים",
    "Very weak password" : "ססמה מאוד חלשה",
    "Weak password" : "ססמה חלשה",
    "So-so password" : "ססמה בינונית",
    "Good password" : "ססמה טובה",
    "Strong password" : "ססמה חזקה",
    "No action available" : "אין פעולה זמינה",
    "Error fetching contact actions" : "שגיאה בקבלת פעולות אנשי הקשר",
    "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
    "restricted" : "מוגבל",
    "invisible" : "בלתי גלוי",
    "Delete" : "מחיקה",
    "Rename" : "שינוי שם",
    "Collaborative tags" : "תגיות שיתופיות",
    "No tags found" : "לא נמצאו תגים",
    "Personal" : "אישי",
    "Users" : "משתמשים",
    "Apps" : "יישומים",
    "Admin" : "מנהל",
    "Help" : "עזרה",
    "Access forbidden" : "הגישה נחסמה",
    "File not found" : "קובץ לא נמצא",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "לא ניתן למצוא את המסמך בשרת. יכול להיות שהשיתוף נמחק או פג?",
    "Back to %s" : "חזרה אל %s",
    "Too many requests" : "יותר מדי בקשות",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "היו יותר מדי בקשות מהרשת שלך. נסה שוב מאוחר יותר, או צור קשר עם מנהל המערכת שלך אם זו שגיאה.",
    "Error" : "שגיאה",
    "Previous" : "הקודם",
    "Internal Server Error" : "שגיאה פנימית בשרת",
    "The server was unable to complete your request." : "השרת לא הצליח להשלים את הבקשה שלך.",
    "If this happens again, please send the technical details below to the server administrator." : "אם דבר כזה קורה שוב, נא לשלוח את הפרטים הטכניים שלהלן למנהל השרת.",
    "More details can be found in the server log." : "פרטים נוספים ניתן למצוא בלוג של הרשת.",
    "Technical details" : "פרטים טכנים",
    "Remote Address: %s" : "כתובת מרוחקת: %s",
    "Request ID: %s" : "מספר זיהוי מבוקש: %s",
    "Type: %s" : "סוג: %s",
    "Code: %s" : "קוד: %s",
    "Message: %s" : "הודעה: %s",
    "File: %s" : "קובץ: %s",
    "Line: %s" : "שורה: %s",
    "Trace" : "עקבות",
    "Security warning" : "אזהרת אבטחה",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיות וקובצי הנתונים שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה־‎.htaccess לא עובד.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "למידע בנוגע להגדרת השרת שלך כראוי, נא לעיין ב<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">תיעוד</a>.",
    "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
    "Username" : "שם משתמש",
    "Show password" : "הצגת ססמה",
    "Storage & database" : "אחסון ומסד נתונים",
    "Data folder" : "תיקיית נתונים",
    "Configure the database" : "הגדרת מסד הנתונים",
    "Only %s is available." : "רק %s זמין.",
    "Install and activate additional PHP modules to choose other database types." : "לבחירת סוגים אחרים של מסדי נתונים יש להתקין ולהפעיל מודולי PHP נוספים.",
    "For more details check out the documentation." : "למידע נוסף יש לבדוק במסמכי התיעוד.",
    "Database user" : "שם משתמש במסד הנתונים",
    "Database password" : "ססמת מסד הנתונים",
    "Database name" : "שם מסד הנתונים",
    "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
    "Database host" : "שרת מסד נתונים",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "נא לציין את מספר הפתחה יחד עם שם המארח (למשל: localhost:5432).",
    "Performance warning" : "אזהרת ביצועים",
    "You chose SQLite as database." : "בחרת ב־SQLite כמסד נתונים.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "יש להשתמש ב־SQLite לסביבות מזעריות או למטרות פיתוח. בסביבת פעילות שגרתית אנו ממליצים על מנגנון מסד נתונים אחר.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "אם יש לך לקוח שמשמש אותך לסנכרון קבצים, השימוש ב־SQLite לא מומלץ עבורך.",
    "Install recommended apps" : "התקנת יישומונים מומלצים",
    "Calendar, Contacts, Talk, Mail & Collaborative editing" : "לוח שנה, אנשי קשר, שיחה, דואר, ועריכה משותפת",
    "Finish setup" : "סיום התקנה",
    "Finishing …" : "מסיים...",
    "Need help?" : "עזרה נזקקת?",
    "See the documentation" : "יש לצפות במסמכי התיעוד",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "נראה שאתה מנסה להתקין מחדש את ה-Nextcloud שלך.אבל הקובץ CAN_INSTALL חסר בספריית ה-config שלך. אנא צור את הקובץ CAN_INSTALL בתיקיית ה-config שלך כדי להמשיך.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "לא ניתן להסיר את CAN_INSTALL מתיקיית ההגדרות. נא להסיר את הקובץ הזה ידנית.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "יישום זה דורש JavaScript לפעולה נכונה. יש {linkstart}לאפשר JavaScript{linkend} ולטעון את העמוד מחדש.",
    "Get your own free account" : "קבלת חשבון משלך בחינם",
    "Skip to main content" : "דילוג לתוכן הראשי",
    "Skip to navigation of app" : "דילוג לניווט של היישומון",
    "More apps" : "יישומים נוספים",
    "More" : "עוד",
    "More apps menu" : "תפריט יישומונים נוספים",
    "Contacts" : "אנשי קשר",
    "Contacts menu" : "תפריט אנשי קשר",
    "Settings menu" : "תפריט הגדרות",
    "Confirm your password" : "אימות הססמה שלך",
    "Connect to your account" : "התחברות לחשבון שלך",
    "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
    "App token" : "אסימון יישום",
    "Grant access" : "הענקת גישה",
    "Alternative log in using app token" : "כניסה חלופית באמצעות אסימון יישומון",
    "Account access" : "גישה לחשבון",
    "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך.",
    "Account connected" : "חשבון מחובר",
    "Your client should now be connected!" : "הלקוח שלך אמור להיות מחובר עכשיו!",
    "You can close this window." : "ניתן לסגור את החלון הזה.",
    "This share is password-protected" : "שיתוף זה מוגן בססמה",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "Two-factor authentication" : "אימות דו־שלבי",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "על החשבון שלך מופעלת אבטחה מוגברת. נא לבחור גורם אימות נוסף:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "לא ניתן לטעון לפחות את אחד משיטות האימות הדו־שלבי שהפעלת. נא ליצור קשר עם מנהל המערכת.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "אימות דו-גורמי נאכף, אך לא הוגדר בחשבון שלך. אנא תמשיך להגדיר אימות דו-גורמי.",
    "Set up two-factor authentication" : "הגדרת אימות דו־שלבי",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא להשתמש באחד מהקודים לצורכי גיבוי כדי להיכנס או ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Use backup code" : "שימוש בקוד גיבוי",
    "Cancel login" : "ביטול התחברות",
    "Setup two-factor authentication" : "הגדרת אימות דו־שלבי",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "על החשבון שלך נאכפת אבטחה מורחבת. נא לבחור איזה ספק להגדיר:",
    "Error while validating your second factor" : "שגיאה בעת אימות הגורם השני",
    "Access through untrusted domain" : "גישה דרך שם מתחם בלתי מהימן",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "נא ליצור קשר עם מנהל השרת שלך. אם הרשאות ניהול השרת הן בידיך, יש לערוך את ההגדרה „trusted_domains” בתוך config/config.php כמו הדוגמה שבתוך ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ניתן למצוא מידע נוסף על אופן ההגדרה של התכונה הזאת ב%1$sתיעוד%2$s.",
    "App update required" : "נדרש עדכון יישום",
    "%1$s will be updated to version %2$s" : "%1$s יעודכן לגרסה %2$s",
    "The following apps will be updated:" : "היישומונים הבאים יעודכנו:",
    "These incompatible apps will be disabled:" : "יישומים לא תואמים ינוטרלו:",
    "The theme %s has been disabled." : "ערכת הנושא %s הושבתה.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "יש לוודא שמסד הנתונים, תיקיית config ותיקיית data גובו לפני המשך התהליך.",
    "Start update" : "התחלת עדכון",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "למניעת פסקי זמן בהתקנות גדולות, ניתן במקום להריץ את הפקודה הבאה בתיקיית ההתקנה שלך:",
    "Detailed logs" : "יומן מפורט",
    "Update needed" : "עדכון נדרש",
    "Please use the command line updater because you have a big instance with more than 50 users." : "נא להשתמש בתכנית העדכון משורת הפקודה כיוון שיש לך עותק גדול עם למעלה מ־50 משתמשים.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "לעזרה יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">תיעוד</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ידוע לי שאם אמשיך דרך מנשק הדפדפן אהיה חשוף לסכנה, שהבקשה עשויה להיקלע לחוסר מענה וכתוצאה מכך אבדן נתונים, אך יש לי גיבוי וידוע לי איך לשחזר את העותק שלי במקרה של כשל.",
    "Upgrade via web on my own risk" : "השדרוג דרך האינטרנט הוא על אחריותי",
    "Maintenance mode" : "מצב תחזוקה",
    "This %s instance is currently in maintenance mode, which may take a while." : "הפעלה %s זו כרגע במצב אחזקה, שתמשך זמן מה.",
    "This page will refresh itself when the instance is available again." : "עמוד זה ירענן את עצמו כאשר העותק ישוב להיות זמין.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
    "Following apps have been disabled: %s" : "היישומים הבאים נוטרלו: %s",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "גרסת ה־PHP הנוכחית שלך היא 5.6. הגרסה העיקרית הנוכחית של Nextcloud היא הגרסה האחרונה שעוד תומכת ב־PHP 5.6. מומלץ לשדרג את גרסה ה־PHP ל־7.0 ומעלה כדי לאפשר את השדרוג ל־Nextcloud 14.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "השימוש בתכונת הדוא״ל המובנית של php אינה נתמכת עוד. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">נא לעדכן את הגדרות שרת הדוא״ל שלך ↖<a/>.",
    "({scope})" : "({scope})",
    "Searching other places" : "מחפש במקומות אחרים",
    "No search results in other folders for {tag}{filter}{endtag}" : "אין תוצאות חיפוש בתיקיות אחרות עבור {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} תוצאת חיפוש בתיקייה אחרות","{count} תוצאות חיפוש בתיקיות אחרות","{count} תוצאות חיפוש בתיקיות אחרות","{count} תוצאות חיפוש בתיקיות אחרות"],
    "Nextcloud {app}" : "{app} מבית Nextcloud",
    "Local document editing back-end used by the OnlyOffice app." : "מנגנון עריכת מסמכים מקומי בו משתמש היישומון OnlyOffice.",
    "Saving..." : "שמירה…",
    "Calendar, Contacts, Talk, Mail & OnlyOffice" : "יומן, אנשי קשר, שיחה, דוא״ל ו־OnlyOffice",
    "Search" : "חיפוש",
    "These apps will be updated:" : "יישומים אלו יעודכנו:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
